local mod = ...



-- Building Asset Processor -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Fire1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Prefabs -------------------------------------------------------------------------------------
mod:registerAssetId("models/Fire1.fbx/Prefab/Clearing", "PREFAB_FIRE_CLEARING")
mod:registerAssetId("models/Fire1.fbx/Prefab/Emitter", "PREFAB_FIRE_EMITTER")
-- mod:registerAssetId("models/Fire1.fbx/Prefab/Emitter/Flare", "PREFAB_FIRE_FLARE")
mod:registerAssetId("models/Fire1.fbx/Prefab/Emitter/Fire", "PREFAB_FIRE_FIRE")
mod:registerAssetId("models/Fire1.fbx/Prefab/Emitter/Smoke", "PREFAB_FIRE_SMOKE")
mod:registerAssetId("models/Fire1.fbx/Prefab/Emitter/Spark", "PREFAB_FIRE_SPARK")

-- mod:registerAssetId("models/Fire1.fbx/Prefab/Origin", "PREFAB_FIRE_ORIGIN")
mod:registerAssetId("models/Fire1.fbx/Prefab/FireStarter.Part", "PREFAB_FIRE_START")

mod:registerAssetId("models/Fire1.fbx/Prefab/FireTower.Part", "PREFAB_FIRE_TOWER")
mod:registerAssetId("models/Fire1.fbx/Prefab/FireTower.Constr", "PREFAB_FIRE_TOWER_CONSTR")
mod:registerAssetId("models/Fire1.fbx/Prefab/FireBrigade.Part", "PREFAB_FIRE_TOWER_BRIGADE")



-- -- Grounding -------------------------------------------------------------------------------------
-- mod:registerPrefabComponent("PREFAB_FIRE_ORIGIN", { DataType = "COMP_GROUNDED", AutoDisable = true } )



-- Platform -------------------------------------------------------------------------------------
mod:configurePrefabFlagList("PREFAB_FIRE_TOWER", { "PLATFORM" })



-- Clear Ground -------------------------------------------------------------------------------------
mod:registerPrefabComponent("PREFAB_FIRE_CLEARING", { DataType = "COMP_BUILDING_PART" } )
mod:registerPrefabComponent("PREFAB_FIRE_CLEARING", {
    DataType = "COMP_DIRT_CIRCLE",
    HardRadius = 0.0,
    SoftRadius = 3.50,
    Strength = 0.25,
    IsPermanent = false,
})


-- Building -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING",
	Id = "BUILDING_FIRE",
	Name = "BUILDING_FIRE_NAME",
	Description = "BUILDING_FIRE_DESC",
	BuildingType = "SERVICE",
	AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
	BuildingPartSetList = {
		{
			Name = "BUILDING_PART_SETLIST_FIRE1_NAME",
			BuildingPartList = {
				"BUILDING_PART_FIRE_TOWER",
				"BUILDING_PART_FIRE_TOWER_BRIGADE",
				"BUILDING_PART_FIRE_START",
			},
        },
    },
    VillagerRequired = { Status = "NEWCOMER", Quantity = 25 },
})



-- Building Part: Fire Tower -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_PART",
    Id = "BUILDING_PART_FIRE_TOWER",
    Name = "BUILDING_PART_FIRE_TOWER_NAME",
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_FIRE_TOWER",
    },
    ConstructionVisual = "PREFAB_FIRE_TOWER_CONSTR",
	BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = polygon.createRectangle( {3.8, 3.8}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true },
			},
		}
	},
    AssetBuildingFunction = "BUILDING_FUNCTION_FIRE_WATCH",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 10 }
        },
        UpkeepCost = { 
            { Resource = "GOLD_COINS", Quantity = 10 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
            },
            {
                { Resource = "PLANK", Quantity = 10 },
            },
            {
                { Resource = "WOOD", Quantity = 5 },
                { Resource = "PLANK", Quantity = 5 },
            },
            {
                { Resource = "WOOD", Quantity = 5 },
                { Resource = "PLANK", Quantity = 5 },
            },
        },
    },
	DesirabilityModifiers = {
        {
            Desirability = "DESIRABILITY_RESIDENTIAL",
            Type = "ADD",
            Radius = 75.0,
            Value = 0.1
    	},
    },
})



-- Building Part: Fire Brigade -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_PART",
    Id = "BUILDING_PART_FIRE_TOWER_BRIGADE",
    Name = "BUILDING_FUNCTION_FIRE_WATER_NAME",
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_FIRE_TOWER_BRIGADE",
    },
    AssetBuildingFunction = "BUILDING_FUNCTION_FIRE_WATER",
	BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = polygon.createRectangle( {3.8, 3.8}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true },
			},
		}
	},
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 30 }
        },
        UpkeepCost = {
            { Resource = "GOLD_COINS", Quantity = 10 }
        },
    },
    IsOnlyAttached = true,
})



-- Job: Fire Watch -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_FIRE_WATCH",
	JobName = "JOB_FIRE_WATCH_NAME",
	JobDescription = "JOB_FIRE_WATCH_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 20,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
})

mod:overrideAsset({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATCH",
    }
})

mod:overrideAsset({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATCH",
    }
})

mod:overrideAsset({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATCH",
    }
})

mod:overrideAsset({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATCH",
    }
})



-- Job: Fire Fighter -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_FIRE_WATER",
	JobName = "JOB_FIRE_WATER_NAME",
	JobDescription = "JOB_FIRE_WATER_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_FIRE_WATER",
    ProductionDelay = 0.5,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
        LeftHandObject = {
            Model = "PREFAB_TOOL_DAIRY_FARMER_BUCKET"
        },
        RightHandObject = {
            Model = "PREFAB_TOOL_DAIRY_FARMER_BUCKET"
        },
		IdleAnimation = "IDLE",
	},
})

mod:overrideAsset({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATER",
    }
})

mod:overrideAsset({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATER",
    }
})

mod:overrideAsset({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATER",
    }
})

mod:overrideAsset({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_FIRE_WATER",
    }
})



-- Building Function: Fire Watch -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_FIRE_WATCH",
    Name = "BUILDING_FUNCTION_FIRE_WATCH_NAME",
    WorkerCapacity = 1,
    RelatedJob = {
        Job = "JOB_FIRE_WATCH",
        Behavior = "BEHAVIOR_WORK",
    },
    InputInventoryCapacity = {
	},
    ResourceListNeeded = {
	},
    ResourceProduced = {
	}
})



-- Building Function: Fire Brigade -------------------------------------------------------------------------------------

-- Number of workers should be 2 if Influence mod is running
local countBrigade = 3
if (foundation.isModLoaded("fca66169-9020-49e8-95fe-e377f4150e09")) then
    countBrigade = 2
end

mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_FIRE_WATER",
    Name = "BUILDING_FUNCTION_FIRE_WATER_NAME",
    WorkerCapacity = countBrigade,
    RelatedJob = {
        Job = "JOB_FIRE_WATER",
        Behavior = "BEHAVIOR_FIRE_WATER",
    },
})



-- Building Part: Start Fire -------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_PART",
    Id = "BUILDING_PART_FIRE_START",
    Name = "BUILDING_PART_FIRE_START_NAME",
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_FIRE_START",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0.0,
            CameraPosition = { 0, 0, 0 },
            OrientationOffset = 0.0,
            CameraPitchOffset = 25.0
        },
    },
	DesirabilityModifiers = {
        {
            Desirability = "DESIRABILITY_RESIDENTIAL",
            Type = "SUBSTRACT",
            Radius = 5.0,
            Value = 1.0
    	},
    },
})